@@ -1,21 +1,15 @@
 package Dist::Zilla::Plugin::ReadmeFromPod;
 our $AUTHORITY = 'cpan:AVAR';
-$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.39';
-use v5.10.1;
-
+$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.40';
 use Moose;
+use List::Util 1.33 qw( first );
+with 'Dist::Zilla::Role::InstallTool' => { -version => 5 }; # after PodWeaver
+with 'Dist::Zilla::Role::FilePruner';
 
-use List::Util 1.33 qw( first none );
 use IO::String;
-use Moose::Util::TypeConstraints qw( enum );
 use Pod::Readme v1.2.0;
 use Path::Tiny 0.004;
 
-with qw( Dist::Zilla::Role::AfterBuild
-  Dist::Zilla::Role::AfterRelease
-  Dist::Zilla::Role::FilePruner
-);
-
 has filename => (
     is => 'ro',
     isa => 'Str',
@@ -31,6 +25,12 @@ sub _build_filename {
     return -e $pod ? $pod : $pm;
 }
 
+has type => (
+    is => 'ro',
+    isa => 'Str',
+    default => 'text',
+);
+
 my %FORMATS = (
     'gfm'      => { class => 'Pod::Markdown::Github' },
     'github'   => { class => 'Pod::Markdown::Github' },
@@ -41,12 +41,6 @@ my %FORMATS = (
     'text'     => { class => 'Pod::Simple::Text' },
 );
 
-has type => (
-    is => 'ro',
-    isa => enum( [ keys %FORMATS ] ),
-    default => 'text',
-);
-
 has pod_class => (
     is => 'ro',
     isa => 'Maybe[Str]',
@@ -66,13 +60,6 @@ has readme => (
     isa => 'Str',
 );
 
-has phase => (
-    is      => 'ro',
-    lazy    => 1,
-    isa     => enum( [qw(build release)] ),
-    default => 'build',
-);
-
 sub prune_files {
     my ($self) = @_;
     my $readme_file = first { $_->name =~ m{^README\z} } @{ $self->zilla->files };
@@ -82,17 +69,8 @@ sub prune_files {
     }
 }
 
-sub after_build {
-    my ($self) = @_;
-    $self->_create_readme if $self->phase eq 'build';
-}
-sub after_release {
-    my ($self) = @_;
-    $self->_create_readme if $self->phase eq 'release';
-}
-
-sub _create_readme {
-    my ($self) = @_;
+sub setup_installer {
+    my ($self, $arg) = @_;
 
     my $pod_class = $self->pod_class;
     my $readme_name = $self->readme;
@@ -121,11 +99,9 @@ sub _create_readme {
         }
     }
 
-    my $source = first { $_->name eq $self->filename } @{ $self->zilla->files };
-
     my $content;
     my $prf = Pod::Readme->new(
-      input_fh          => IO::String->new( $source->content ),
+      input_file        => $self->filename,
       translate_to_fh   => IO::String->new($content),
       translation_class => $pod_class,
       force             => 1,
@@ -157,6 +133,7 @@ sub _create_readme {
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
+1;
 
 =head1 NAME
 
@@ -172,42 +149,41 @@ Dist::Zilla::Plugin::ReadmeFromPod - dzil plugin to generate README from POD
     filename = lib/XXX.pod
     type = markdown
     readme = READTHIS.md
-    phase = build
 
 =head1 DESCRIPTION
 
 This plugin generates the F<README> from C<main_module> (or specified)
 by L<Pod::Readme>.
 
-=head1 ATTRIBUTES
+=head2 Options
 
 The following options are supported:
 
-=head2 filename
+=head3 C<filename>
 
 The name of the file to extract the F<README> from. This defaults to
 the main module of the distribution.
 
-=head2 type
+=head3 C<type>
 
 The type of F<README> you want to generate. This defaults to "text".
 
 Other options are "html", "pod", "markdown" and "rtf".
 
-=head2 pod_class
+=head3 C<pod_class>
 
 This is the L<Pod::Simple> class used to translate a file to the
 format you want. The default is based on the L</type> setting, but if
 you want to generate an alternative type, you can set this option
 instead.
 
-=head2 readme
+=head3 C<readme>
 
 The name of the file, which defaults to one based on the L</type>.
 
-=head2 phase
+=head2 Conflicts with Other Plugins
 
-This indicates what phase to build the README file from. It is either C<build> (the default) or C<release>.
+We will remove the README created by L<Dist::Zilla::Plugin::Readme> automatically.
 
 =head1 AUTHORS
 
@@ -217,11 +193,9 @@ E<AElig>var ArnfjE<ouml>rE<eth> Bjarmason <avar@cpan.org>
 Robert Rothenberg <rrwo@cpan.org> modified this plugin to use
 L<Pod::Readme>.
 
-Some parts of the code were borrowed from L<Dist::Zilla::Plugin::ReadmeAnyFromPod>.
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2025 Fayland Lam <fayland@gmail.com> and E<AElig>var
+Copyright 2010-2015 Fayland Lam <fayland@gmail.com> and E<AElig>var
 ArnfjE<ouml>rE<eth> Bjarmason <avar@cpan.org>
 
 This program is free software, you can redistribute it and/or modify
